package Bio::MUST::Drivers::Hmmer::Model;
# ABSTRACT: Internal class for HMMER3 driver
# CONTRIBUTOR: Arnaud DI FRANCO <arnaud.difranco@gmail.com>
$Bio::MUST::Drivers::Hmmer::Model::VERSION = '0.161550';
use Moose;
use namespace::autoclean;

use Carp;
use Path::Class;

use autodie;
use feature qw(say);

use Bio::MUST::Core::Types;


has 'file' => (
    is       => 'ro',
    isa      => 'File::Temp',
    required => 1,
);

has $_ => (
    is       => 'ro',
    isa      => 'Int',
    required => 1,
) for qw(cksum nseq leng);

has $_ => (
    is       => 'ro',
    isa      => 'Num',
    required => 1,
) for qw(effn);

has $_ => (
    is       => 'ro',
    isa      => 'Maybe[Str]',
    required => 1,
) for qw(alph cons cs map mm name rf);


around BUILDARGS => sub {
    my %args = @_;

    my $profile_file = file( $args{'file'} );
    my @profile_content = $profile_file->slurp( chomp => 1 );
    my @profile_header = @profile_content[0..15];

    for my $idx ( 1..8, 10..12 ) {
        my ($key, $value) = split /\s+/xms, $profile_header[$idx];
        $args{ lc($key) } = $value;
    }

    return \%args;
};

__PACKAGE__->meta->make_immutable;
1;

__END__

=pod

=head1 NAME

Bio::MUST::Drivers::Hmmer::Model - Internal class for HMMER3 driver

=head1 VERSION

version 0.161550

=head1 SYNOPSIS

    # TODO

=head1 DESCRIPTION

    # TODO

=head1 AUTHOR

Denis BAURAIN <denis.baurain@ulg.ac.be>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by University of Liege / Unit of Eukaryotic Phylogenomics / Denis BAURAIN.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
